Subject: bug#21988: 24.5; keyword 'our' not being fontified in perl-mode

From: Thomas Uhle <[email-masked]>
Date: Sun, 22 Nov 2015 16:38:01 +0100 (CET)

Hello,

the keyword 'our' opposed to the keywords 'my' and 'local' is not being 
fontified in perl-mode. The simple patch that is attached to this bug 
report is fixing this issue.

Best regards,

Thomas Uhle

--- lisp/progmodes/perl-mode.el~	2015-06-14 21:47:29 +0200
+++ lisp/progmodes/perl-mode.el	2015-11-22 16:01:26 +0100
@@ -194,8 +194,8 @@
                             "BEGIN" "END" "return" "exec" "eval") t)
               "\\>")
      ;;
-     ;; Fontify local and my keywords as types.
-     ("\\<\\(local\\|my\\)\\>" . font-lock-type-face)
+     ;; Fontify local, my and our keywords as types.
+     ("\\<\\(local\\|my\\|our\\)\\>" . font-lock-type-face)
      ;;
      ;; Fontify function, variable and file name references.
      ("&\\(\\sw+\\(::\\sw+\\)*\\)" 1 font-lock-function-name-face)